<?php
declare(strict_types=1);

namespace PunktDe\SiteSpecifics\Tests\Functional\NodeTypePostProcessor;

/*
 *  (c) 2021 punkt.de GmbH - Karlsruhe, Germany - http://punkt.de
 *  All rights reserved.
 */

use Neos\ContentRepository\Domain\Service\NodeTypeManager;
use Neos\Flow\Tests\FunctionalTestCase;
use Neos\Utility\Arrays;
use PunktDe\SiteSpecifics\Service\SiteDeterminationService;

class SiteSpecificNodeTypePostProcessorTest extends FunctionalTestCase
{

    protected ?NodeTypeManager $nodeTypeManager;


    public function setUp(): void
    {
        parent::setUp(); // TODO: Change the autogenerated stub

        $this->nodeTypeManager = $this->objectManager->get(NodeTypeManager::class);
        $this->nodeTypeManager->overrideNodeTypes([]);
    }

    public function configurationTestDataProvider(): array
    {
        return [
            'simple value override' => [
                'currentSite' => 'mySite',
                'path' => 'ui.group',
                'config' => 'not-shown'
            ],
            'no override if site does not match' => [
                'currentSite' => 'anotherSite',
                'path' => 'ui.group',
                'config' => 'basic'
            ],
        ];
    }


    /**
     * @dataProvider configurationTestDataProvider
     * @test
     * @param string $currentSite
     * @param string $path
     * @param $config
     * @throws \Neos\ContentRepository\Exception\NodeTypeNotFoundException
     */
    public function siteSpecificOverrides(string $currentSite, string $path, $config): void
    {
        SiteDeterminationService::$siteName = $currentSite;

        $nodeTypeConfiguration = $this->nodeTypeManager->getNodeType('PunktDe.SiteSpecifics:Content.Headline')->getFullConfiguration();
        self::assertEquals($config, Arrays::getValueByPath($nodeTypeConfiguration, $path));
    }
}
